==> jc-1.4.0.tar.gz: soot/jimple/parser/node/APlusBinop.h <==
// public final class soot.jimple.parser.node.APlusBinop

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d61a110fde2eeedf soot_jimple_parser_node_APlusBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_APlusBinop_H_
#define _JC_soot_jimple_parser_node_APlusBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TPlus$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_APlusBinop$sub_refs	_jc_soot_jimple_parser_node_APlusBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_APlusBinop$sub_nonrefs	_jc_soot_jimple_parser_node_APlusBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_APlusBinop$refs	_jc_soot_jimple_parser_node_APlusBinop$refs;
typedef struct _jc_soot_jimple_parser_node_APlusBinop$nonrefs	_jc_soot_jimple_parser_node_APlusBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_APlusBinop$object	_jc_soot_jimple_parser_node_APlusBinop$object;

typedef const struct _jc_soot_jimple_parser_node_APlusBinop$vmethods	_jc_soot_jimple_parser_node_APlusBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_APlusBinop$vtable	_jc_soot_jimple_parser_node_APlusBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_APlusBinop$vtype	_jc_soot_jimple_parser_node_APlusBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_APlusBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *);
extern void _jc_soot_jimple_parser_node_APlusBinop$method$_init$ad94d2aeb90ccb6e(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *, struct _jc_soot_jimple_parser_node_TPlus$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_APlusBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_APlusBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *);
extern struct _jc_soot_jimple_parser_node_TPlus$object *_jc_soot_jimple_parser_node_APlusBinop$method$getPlus$de2fff52e36bb326(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *);
extern void _jc_soot_jimple_parser_node_APlusBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_APlusBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_APlusBinop$method$setPlus$067c7a12c1a8c2bf(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *, struct _jc_soot_jimple_parser_node_TPlus$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_APlusBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_APlusBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_APlusBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_APlusBinop$method_info$getPlus$de2fff52e36bb326;
extern _jc_method _jc_soot_jimple_parser_node_APlusBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_APlusBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_APlusBinop$method_info$setPlus$067c7a12c1a8c2bf;
extern _jc_method _jc_soot_jimple_parser_node_APlusBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_APlusBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *);
	struct _jc_soot_jimple_parser_node_TPlus$object	*(*getPlus$de2fff52e36bb326)(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setPlus$067c7a12c1a8c2bf)(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *, struct _jc_soot_jimple_parser_node_TPlus$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_APlusBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_APlusBinop$vmethods	soot_jimple_parser_node_APlusBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_APlusBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_APlusBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_APlusBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TPlus$object	*__5fplus__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_APlusBinop$refs {
    _jc_soot_jimple_parser_node_APlusBinop$sub_refs	soot_jimple_parser_node_APlusBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_APlusBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_APlusBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_APlusBinop$sub_nonrefs	soot_jimple_parser_node_APlusBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_APlusBinop$object {
	_jc_soot_jimple_parser_node_APlusBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_APlusBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_APlusBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_APlusBinop$vtype _jc_soot_jimple_parser_node_APlusBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_APlusBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_APlusBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_APlusBinop_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/APlusBinop.h <==
// public final class soot.jimple.parser.node.APlusBinop

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d61a110fde2eeedf soot_jimple_parser_node_APlusBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_APlusBinop_H_
#define _JC_soot_jimple_parser_node_APlusBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TPlus$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_APlusBinop$sub_refs	_jc_soot_jimple_parser_node_APlusBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_APlusBinop$sub_nonrefs	_jc_soot_jimple_parser_node_APlusBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_APlusBinop$refs	_jc_soot_jimple_parser_node_APlusBinop$refs;
typedef struct _jc_soot_jimple_parser_node_APlusBinop$nonrefs	_jc_soot_jimple_parser_node_APlusBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_APlusBinop$object	_jc_soot_jimple_parser_node_APlusBinop$object;

typedef const struct _jc_soot_jimple_parser_node_APlusBinop$vmethods	_jc_soot_jimple_parser_node_APlusBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_APlusBinop$vtable	_jc_soot_jimple_parser_node_APlusBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_APlusBinop$vtype	_jc_soot_jimple_parser_node_APlusBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_APlusBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_APlusBinop$method$_init$ad94d2aeb90ccb6e(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *, struct _jc_soot_jimple_parser_node_TPlus$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_APlusBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_APlusBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TPlus$object *_jc_soot_jimple_parser_node_APlusBinop$method$getPlus$de2fff52e36bb326(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_APlusBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_APlusBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_APlusBinop$method$setPlus$067c7a12c1a8c2bf(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *, struct _jc_soot_jimple_parser_node_TPlus$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_APlusBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_APlusBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_APlusBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_APlusBinop$method_info$getPlus$de2fff52e36bb326;
extern _jc_method _jc_soot_jimple_parser_node_APlusBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_APlusBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_APlusBinop$method_info$setPlus$067c7a12c1a8c2bf;
extern _jc_method _jc_soot_jimple_parser_node_APlusBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_APlusBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TPlus$object	*(*getPlus$de2fff52e36bb326)(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setPlus$067c7a12c1a8c2bf)(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *, struct _jc_soot_jimple_parser_node_TPlus$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_APlusBinop$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_APlusBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_APlusBinop$vmethods	soot_jimple_parser_node_APlusBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_APlusBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_APlusBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_APlusBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TPlus$object	*__5fplus__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_APlusBinop$refs {
    _jc_soot_jimple_parser_node_APlusBinop$sub_refs	soot_jimple_parser_node_APlusBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_APlusBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_APlusBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_APlusBinop$sub_nonrefs	soot_jimple_parser_node_APlusBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_APlusBinop$object {
	_jc_soot_jimple_parser_node_APlusBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_APlusBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_APlusBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_APlusBinop$vtype _jc_soot_jimple_parser_node_APlusBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_APlusBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_APlusBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_APlusBinop_H_ */
